@@ -1,6 +1,6 @@
 /* -*- c-file-style: "ruby"; indent-tabs-mode: nil -*- */
 /*
- *  Copyright (C) 2011-2013  Ruby-GNOME2 Project Team
+ *  Copyright (C) 2011-2014  Ruby-GNOME2 Project Team
  *  Copyright (C) 2002-2005  Ruby-GNOME2 Project
  *  Copyright (C) 2002,2003  Masahiro Sakai
  *
@@ -20,7 +20,8 @@
  *  MA  02110-1301  USA
  */
 
-#include <glib.h>
+#include <glib-object.h>
+
 #include "ruby.h"
 
 #include "rbglibdeprecated.h"
@@ -34,7 +35,7 @@ extern "C" {
 #endif /* __cplusplus */
 
 #define RBGLIB_MAJOR_VERSION 2
-#define RBGLIB_MINOR_VERSION 1
+#define RBGLIB_MINOR_VERSION 2
 #define RBGLIB_MICRO_VERSION 0
 
 #ifndef RSTRING_PTR
@@ -123,7 +124,7 @@ extern "C" {
 #define G_DEF_ERROR(domain, name, module, parent, gtype)         \
     rbgerr_define_gerror(domain, name, module, parent, gtype)
 #define G_DEF_ERROR2(domain, name, module, parent) \
-    rbgerr_define_gerror(domain, name, module, parent, Qnil)
+    rbgerr_define_gerror(domain, name, module, parent, G_TYPE_INVALID)
 
 #if defined(G_PLATFORM_WIN32) && !defined(RUBY_GLIB2_STATIC_COMPILATION)
 #  ifdef RUBY_GLIB2_COMPILATION
@@ -187,7 +188,7 @@ extern void rbg_scan_options(VALUE options, ...);
 
 /* rbgerror.h */
 extern VALUE rbgerr_gerror2exception(GError *error);
-extern VALUE rbgerr_define_gerror(GQuark domain, const gchar* name, VALUE module, VALUE parent, VALUE gtype);
+extern VALUE rbgerr_define_gerror(GQuark domain, const gchar* name, VALUE module, VALUE parent, GType gtype);
 
 extern VALUE rbglib_int64_to_num(guint64 val);
 extern VALUE rbglib_uint64_to_num(guint64 val);
