@@ -66,11 +66,17 @@ extern "C" {
 #define RG_REG_SYMBOL_GETTER(name) \
         rbgobj_register_property_getter(CLASS2GTYPE(RG_TARGET_NAMESPACE), name, rbgutil_sym_g2r_func)
 
+#define RG_REPLACE_SET_PROPERTY(name, args)   \
+    G_REPLACE_SET_PROPERTY(RG_TARGET_NAMESPACE, #name, rg_set_ ## name, args)
+#define RG_REPLACE_GET_PROPERTY(name, args)   \
+    G_REPLACE_GET_PROPERTY(RG_TARGET_NAMESPACE, #name, rg_get_ ## name, args)
+#define RG_REPLACE_ACTION(name, args)                               \
+    G_REPLACE_ACTION(RG_TARGET_NAMESPACE, #name, rg_ ## name, args)
+
 #define G_REPLACE_SET_PROPERTY(klass, name, function, args) \
     rb_undef_method(klass, "set_" name); \
-    rb_define_method(klass, "set_" name, function, args); \
     rb_undef_method(klass, name "="); \
-    G_DEF_SETTER(klass, name)
+    rbg_define_method(klass, "set_" name, function, args)
 
 #define G_REPLACE_GET_PROPERTY(klass, name, function, args) \
     rb_undef_method(klass, name); \
@@ -98,6 +104,8 @@ extern void rbgutil_stop_callback_dispatch_thread(void);
 extern VALUE rbgutil_string_set_utf8_encoding(VALUE string);
 extern gboolean rbgutil_key_equal(VALUE rb_string, const char *key);
 
+extern const gchar *rbg_inspect(VALUE object);
+
 /*< protected >*/
 RUBY_GLIB2_VAR ID rbgutil_id_module_eval;
 extern void rbgutil_glibid_r2g_func(VALUE from, GValue* to);
