@@ -20,7 +20,7 @@ end
 $LOAD_PATH.unshift(mkmf_gnome2_dir.to_s)
 
 module_name = "gstreamer"
-package_id = "gstreamer-0.10"
+package_id = "gstreamer-1.0"
 
 begin
   require 'mkmf-gnome2'
@@ -30,9 +30,11 @@ rescue LoadError
   require 'mkmf-gnome2'
 end
 
-["glib2"].each do |package|
+["glib2", "gobject-introspection"].each do |package|
   directory = "#{package}#{version_suffix}"
-  build_dir = "#{directory}/tmp/#{RUBY_PLATFORM}/#{package}/#{RUBY_VERSION}"
+  build_base_path = "#{directory}/tmp/#{RUBY_PLATFORM}"
+  package_library_name = package.gsub(/-/, "_")
+  build_dir = "#{build_base_path}/#{package_library_name}/#{RUBY_VERSION}"
   add_depend_package(package, "#{directory}/ext/#{package}",
                      top_dir.to_s,
                      :top_build_dir => top_build_dir.to_s,
@@ -41,19 +43,16 @@ end
 
 setup_win32(module_name, base_dir)
 
-PKGConfig.have_package(package_id) or exit 1
-PKGConfig.have_package('gstreamer-plugins-base-0.10') or exit 1
-
-have_header("unistd.h")
-have_header("io.h")
-
-if have_library("gstinterfaces-0.10") and
-    have_header("gst/interfaces/xoverlay.h")
-  $CFLAGS += " -DHAVE_GST_OVERLAY"
+unless required_pkg_config_package(package_id,
+                                   :debian => "libgstreamer1.0-dev",
+                                   :redhat => "gstreamer-devel",
+                                   :homebrew => "gstreamer",
+                                   :macports => "gstreamer")
+  exit(false)
 end
 
-if PKGConfig.have_package("gstreamer-pbutils-0.10")
-  $CFLAGS += " -DHAVE_GST_PBUTILS"
+unless PKGConfig.have_package("gobject-introspection-1.0")
+  exit(false)
 end
 
 create_pkg_config_file("Ruby/GStreamer", package_id)
@@ -66,4 +65,3 @@ if pkg_config_dir.is_a?(String)
     makefile.puts("pkgconfigdir=#{pkg_config_dir}")
   end
 end
-
