@@ -16,16 +16,6 @@ require "tempfile"
 require "date"
 require "glib2"
 require "gdk_pixbuf2"
-begin
-  require "gtk2"
-rescue LoadError
-rescue
-  if defined?(Gtk::InitError) and $!.class == Gtk::InitError
-    # ignore
-  else
-    raise
-  end
-end
 begin
   require "cairo"
 rescue LoadError
@@ -36,7 +26,7 @@ vendor_dir = base_dir + "vendor" + "local"
 vendor_bin_dir = vendor_dir + "bin"
 GLib.prepend_dll_path(vendor_bin_dir)
 begin
-  major, minor, micro, = RUBY_VERSION.split(/\./)
+  major, minor, = RUBY_VERSION.split(/\./)
   require "#{major}.#{minor}/poppler.so"
 rescue LoadError
   require "poppler.so"
